pub struct QwalReceiptV3 {
pub request_id: String,
pub request_digest: LogHash,
pub result_blob: Vec<u8>,
}Expand description
One successful member of a QWAL v3 batch.
The decided entry anchor is intentionally absent: every receipt in the envelope is installed at the single anchor of the log entry carrying the batch.
Fields
request_id: Stringrequest_digest: LogHashresult_blob: Vec<u8>Trait Implementations
Sourceimpl Clone for QwalReceiptV3
impl Clone for QwalReceiptV3
Sourcefn clone(&self) -> QwalReceiptV3
fn clone(&self) -> QwalReceiptV3
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QwalReceiptV3
impl Debug for QwalReceiptV3
Sourceimpl<'de> Deserialize<'de> for QwalReceiptV3
impl<'de> Deserialize<'de> for QwalReceiptV3
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for QwalReceiptV3
Sourceimpl PartialEq for QwalReceiptV3
impl PartialEq for QwalReceiptV3
Sourceimpl Serialize for QwalReceiptV3
impl Serialize for QwalReceiptV3
impl StructuralPartialEq for QwalReceiptV3